package main

import (
	"flag"
	"fmt"
	"os"

	"file-checksum-monitor/internal/library"
)

func main() {
	dbPath := "libraries.db"
	manager, err := library.NewLibraryManager(dbPath)
	if err != nil {
		fmt.Printf("Error initializing LibraryManager: %v\n", err)
		return
	}

	addCmd := flag.NewFlagSet("add", flag.ExitOnError)
	scanCmd := flag.NewFlagSet("scan", flag.ExitOnError)
	compareCmd := flag.NewFlagSet("compare", flag.ExitOnError)

	addName := addCmd.String("name", "", "Name of the library")
	addDir := addCmd.String("directory", "", "Path to the library directory")

	scanName := scanCmd.String("name", "", "Name of the library to scan")

	compareName := compareCmd.String("name", "", "Name of the library to compare")

	if len(os.Args) < 2 {
		fmt.Println("Expected 'add', 'scan', or 'compare' subcommands")
		os.Exit(1)
	}

	switch os.Args[1] {
	case "add":
		addCmd.Parse(os.Args[2:])
		if *addName == "" || *addDir == "" {
			fmt.Println("Usage: add -name <library_name> -directory <directory_path>")
			os.Exit(1)
		}
		if err := manager.AddLibrary(*addName, *addDir); err != nil {
			fmt.Printf("Error adding library: %v\n", err)
		}
	case "scan":
		scanCmd.Parse(os.Args[2:])
		if *scanName == "" {
			fmt.Println("Usage: scan -name <library_name>")
			os.Exit(1)
		}
		if err := manager.ScanLibrary(*scanName); err != nil {
			fmt.Printf("Error scanning library: %v\n", err)
		}
	case "compare":
		compareCmd.Parse(os.Args[2:])
		if *compareName == "" {
			fmt.Println("Usage: compare -name <library_name>")
			os.Exit(1)
		}
		if err := manager.CompareLibrary(*compareName); err != nil {
			fmt.Printf("Error comparing library: %v\n", err)
		}
	default:
		fmt.Println("Unknown subcommand")
		os.Exit(1)
	}
}
